==> klarna-module-kp-3.2.0.zip: Model/Api/Response.php <==
<?php
/**
 * This file is part of the Klarna KP module
 *
 * (c) Klarna Bank AB (publ)
 *
 * For the full copyright and license information, please view the NOTICE
 * and LICENSE files that were distributed with this source code.
 */
namespace Klarna\Kp\Model\Api;

use Klarna\Kp\Api\Data\ResponseInterface;

class Response implements ResponseInterface
{
    use Export;

    /**
     * @var string
     */
    protected $session_id;

    /**
     * @var string
     */
    protected $client_token;

    /**
     * @var int
     */
    protected $fraud_status;

    /**
     * @var string
     */
    protected $redirect_url;

    /**
     * @var string
     */
    protected $order_id;

    /**
     * @var int
     */
    protected $response_code = 418;

    /**
     * @var  string
     */
    protected $message;

    /**
     * Response constructor.
     *
     * @param array $data
     */
    public function __construct($data = [])
    {
        foreach ($data as $key => $value) {
            if (property_exists($this, $key)) {
                $this->$key = $value;
                $this->exports[] = $key;
            }
        }
    }

    /**
     * @return string
     */
    public function getSessionId()
    {
        return $this->session_id;
    }

    /**
     * @return string
     */
    public function getClientToken()
    {
        return $this->client_token;
    }

    /**
     * @return int
     */
    public function getResponseCode()
    {
        return $this->response_code;
    }

    /**
     * @return string
     */
    public function getOrderId()
    {
        return $this->order_id;
    }

    /**
     * @return string
     */
    public function getRedirectUrl()
    {
        return $this->redirect_url;
    }

    /**
     * @return int
     */
    public function getFraudStatus()
    {
        return $this->fraud_status;
    }

    /**
     * @return bool
     */
    public function getIsSuccessfull()
    {
        return in_array($this->response_code, [200, 201, 204], false);
    }

    /**
     * @return string
     */
    public function getMessage()
    {
        return $this->message;
    }
}

==> klarna-module-kp-4.0.2.zip: Model/Api/Response.php <==
<?php
/**
 * This file is part of the Klarna KP module
 *
 * (c) Klarna Bank AB (publ)
 *
 * For the full copyright and license information, please view the NOTICE
 * and LICENSE files that were distributed with this source code.
 */
namespace Klarna\Kp\Model\Api;

use Klarna\Kp\Api\Data\ResponseInterface;

class Response implements ResponseInterface
{
    use Export;

    /**
     * @var string
     */
    protected $session_id;

    /**
     * @var string
     */
    protected $client_token;

    /**
     * @var int
     */
    protected $fraud_status;

    /**
     * @var string
     */
    protected $redirect_url;

    /**
     * @var string
     */
    protected $order_id;

    /**
     * @var int
     */
    protected $response_code = 418;

    /**
     * @var  string
     */
    protected $message;

    /**
     * @var array
     */
    protected $payment_method_categories;

    /**
     * Response constructor.
     *
     * @param array $data
     */
    public function __construct($data = [])
    {
        foreach ($data as $key => $value) {
            if (property_exists($this, $key)) {
                $this->$key = $value;
                $this->exports[] = $key;
            }
        }
    }

    /**
     * @return string
     */
    public function getSessionId()
    {
        return $this->session_id;
    }

    /**
     * @return string
     */
    public function getClientToken()
    {
        return $this->client_token;
    }

    /**
     * @return int
     */
    public function getResponseCode()
    {
        return $this->response_code;
    }

    /**
     * @return string
     */
    public function getOrderId()
    {
        return $this->order_id;
    }

    /**
     * @return string
     */
    public function getRedirectUrl()
    {
        return $this->redirect_url;
    }

    /**
     * @return array
     */
    public function getPaymentMethodCategories()
    {
        return $this->payment_method_categories;
    }

    /**
     * @return int
     */
    public function getFraudStatus()
    {
        return $this->fraud_status;
    }

    /**
     * @return bool
     */
    public function getIsSuccessfull()
    {
        return in_array($this->response_code, [200, 201, 204], false);
    }

    /**
     * @return string
     */
    public function getMessage()
    {
        return $this->message;
    }
}
